#! /usr/bin/python
# This Python file uses the following encoding: utf-8
"""
Grupo SELCO
Programa para emissão de boleto bancário via PDF
Dependência: reportlab, rlbarcode, python-devel
Por: Armando Roque Ferreira Pinto
Inicio: 22/09/2006 Término 25/09/2006

Medidas expressas em mm (milimetros)

Agradecimentos ao Luciano Pacheco da lista Python-Brasil por ter visto o erro do método image no Canvas.

Para inscrever na lista envie um e-mail para
python-br-subscribe@yahoogroups.com.br
e confirme a inscrição com o e-mail

Atualizações
Autor    Data       Descrição
Armando  25/09/2006

"""

"""
Se informar um parametro na chamada do boleto, serah o nome do arquivo com dados a serem lido,
do contrario, vai tentar usar /tmp/boleto.dad
"""

from reportlab.graphics.barcode.common import *
from reportlab.lib import colors
from reportlab.lib.units import mm
from reportlab.pdfgen.canvas import Canvas
from reportlab.platypus import Frame
import os
import time

from SigUtils.formatastring import formataString
from SigUtils import datas
from SigUtils import calcDigito


_pos = calcDigito.__file__.find('calcDigito')
dirImg = calcDigito.__file__[:_pos] + 'boleto/logos/'


class Banco(object):
    def __init__(self):
        self.localPagamento = 'PAGAVEL EM QUALQUER AGENCIA BANCARIA'
        self.formato = 'B'  # B=Boleto(default) C=Carnet(3 por folha
        self.numeroBacen = None
        self.convenio = None
        self.agencia = None
        self.conta = None
        self.conta_dv = None
        self.carteira = None
        self.moeda = '9'
        self.modalidade = '01'


class Cedente(object):
    def __init__(self):
        self.nome = None
        self.CpfCnpj = None
        self.telefone = None
        self.aceite = 'S'
        self.especiedoc = 'DM'
        self.especiemon = 'R$'
        self.impressora = None
        self.cedente_logo = ''


class Titulo(object):
    def __init__(self):
        # Dados do titulo
        self.sacadoNome = None
        self.sacadoCodigo = None
        self.sacadoCpfCnpj = None
        self.enderecoRua = None
        self.enderecoNumero = None
        self.enderecoBairro = None
        self.enderecoCidade = None
        self.enderecoEstado = None
        self.enderecoCep = None
        self.documento = None
        self.emissao = None
        self.nossoNroSeq = None
        self.valor = None
        self.vencimento = None
        self.observacoes = []
        self.codigoBarras = None


class Boleto(object):
    def __init__(self):
        self.banco = Banco()
        self.titulo = Titulo()
        self.cedente = Cedente()
        self.__titulos = []
        self.nossoNumeroCompleto = None
        self.nossoNumeroCompletoEditado = None
        self.__campoLivre = None

    def processaTitulo(self):
        self.__titulos.append(self.titulo)
        self.titulo = Titulo()

    def gerarBoleto(self):
        def _imprimirBoleto():
            self.FONTE_FORM = 'Helvetica'
            self.FONTE_FORM_TAM = 6
            self.FONTE_FORM_TAM_ID = 10
            self.FONTE_DADOS = 'Times-Roman'
            self.FONTE_DADOS_TAM = 10
            # O aceite para o banco ITAU deve ser 'N'
            if self.banco.numeroBacen == '341':
                self.cedente.aceite = 'N'
            # Logomarca da empresa
            try:
                boleto.drawImage(image=self.cedente.cedente_logo, x=7 * mm, y=280 * mm, width=30 * mm,
                                 height=11 * mm)
            except:
                pass

            boleto.setStrokeColor(colors.black)
            boleto.setLineWidth(0.1)
            boleto.setFont('Helvetica-Bold', 14)
            try:
                boleto.drawImage(image=dirImg + '%s.jpg' % self.banco.numeroBacen, x=160 * mm,
                                 y=250 * mm,
                                 width=32 * mm, height=8 * mm)
                boleto.drawImage(image=dirImg + '%s.jpg' % self.banco.numeroBacen, x=007 * mm,
                                 y=229 * mm,
                                 width=32 * mm, height=8 * mm)
                boleto.drawImage(image=dirImg + '%s.jpg' % self.banco.numeroBacen, x=007 * mm,
                                 y=112 * mm,
                                 width=32 * mm, height=8 * mm)
            except:
                pass

            # codigo do banco
            boleto.drawString(43 * mm, 229 * mm, self.bancoComDigito)
            boleto.drawString(43 * mm, 112 * mm, self.bancoComDigito)

            # telefone da empresa
            boleto.setFont('Helvetica-Bold', 12)
            boleto.drawString(7 * mm, 275 * mm, self.cedente.telefone)

            boleto.setStrokeColor(colors.black)
            boleto.setFillColor(colors.black)

            # Recibo de entrega
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM)
            boleto.drawString(7 * mm, 270 * mm, 'Pagador:')
            boleto.drawString(7 * mm, 266 * mm, 'Endereço:')
            boleto.drawString(7 * mm, 258 * mm, 'Documento:')
            boleto.drawString(7 * mm, 254 * mm, 'Emissão:')
            boleto.drawString(7 * mm, 250 * mm, 'Data:')
            boleto.drawString(80 * mm, 258 * mm, 'Valor:')
            boleto.drawString(80 * mm, 254 * mm, 'Vencimento:')
            boleto.drawString(80 * mm, 250 * mm, 'Assinatura: _______________________________')

            boleto.drawString(7 * mm, 217 * mm, 'Data do documento')
            boleto.drawString(41 * mm, 217 * mm, 'No. do documento')
            boleto.drawString(71 * mm, 217 * mm, 'Espécie doc')
            boleto.drawString(91 * mm, 217 * mm, 'Aceite')
            boleto.drawString(114 * mm, 217 * mm, 'Data do processamento')
            boleto.drawString(160 * mm, 217 * mm, 'Agência/Código do Beneficiário')
            boleto.drawString(7 * mm, 209 * mm, 'Uso do banco')
            boleto.drawString(7 * mm, 225 * mm, 'Beneficiário')
            boleto.drawString(160 * mm, 225 * mm, 'Vencimento')
            boleto.drawString(41 * mm, 209 * mm, 'Carteira')
            boleto.drawString(56 * mm, 209 * mm, 'Espécie')
            boleto.drawString(71 * mm, 209 * mm, 'Quantidade')
            boleto.drawString(71 * mm, 205 * mm, '')

            boleto.drawString(123 * mm, 206 * mm, 'x')

            boleto.drawString(124 * mm, 209 * mm, 'Valor')
            boleto.drawString(124 * mm, 205 * mm, '')
            boleto.drawString(160 * mm, 209 * mm, 'Nosso número')
            boleto.drawString(7 * mm, 202 * mm, 'Instruções de responsabilidade do Beneficiário. Qualquer dúvida sobre este boleto, contate o Beneficiário')
            boleto.drawString(160 * mm, 201 * mm, '(=) Valor do documento')
            boleto.drawString(160 * mm, 193 * mm, '(-) Desconto/Abatimento')
            boleto.drawString(160 * mm, 185 * mm, '(-) Outras deduções')
            boleto.drawString(160 * mm, 177 * mm, '(+) Mora/Multa')
            boleto.drawString(160 * mm, 169 * mm, '(+) Outros acréscimos')
            boleto.drawString(160 * mm, 161 * mm, '(=) Valor cobrado')
            boleto.drawString(7 * mm, 154 * mm, 'Pagador')
            boleto.drawString(7 * mm, 140 * mm, 'Pagador/avalista')
            boleto.drawString(135 * mm, 140 * mm, 'CPF/CNPJ')
            boleto.drawString(151 * mm, 137 * mm, 'Autenticação mecânica')

            boleto.setFont('Helvetica-Bold', 14)
            boleto.drawString(58 * mm, 229 * mm, _linhaDigitavel)

            boleto.setFont(self.FONTE_DADOS, self.FONTE_DADOS_TAM)
            boleto.drawString(20 * mm, 270 * mm, _titulo.sacadoNome)
            boleto.drawString(135 * mm, 270 * mm, 'CPF/CNPJ: ' + _titulo.sacadoCpfCnpj)
            boleto.drawString(135 * mm, 266 * mm, 'Nosso Número: ' + str(self.nossoNumeroCompletoEditado))
            boleto.drawString(20 * mm, 266 * mm, _titulo.endereco)
            boleto.drawString(20 * mm, 262 * mm, _titulo.endereco1)
            boleto.drawString(20 * mm, 258 * mm, _titulo.documento)
            boleto.drawString(20 * mm, 254 * mm, _titulo.emissao)
            boleto.drawString(96 * mm, 258 * mm, _titulo.valor)
            boleto.drawString(96 * mm, 254 * mm, _titulo.vencimento)

            boleto.drawString(7 * mm, 221 * mm, self.linhaCedente)
            boleto.drawString(180 * mm, 221 * mm, _titulo.vencimento)
            boleto.drawString(7 * mm, 213 * mm, _titulo.emissao)
            boleto.drawString(41 * mm, 213 * mm, _titulo.documento)
            boleto.drawString(71 * mm, 213 * mm, self.cedente.especiedoc)
            boleto.drawString(91 * mm, 213 * mm, self.cedente.aceite)
            boleto.drawString(114 * mm, 213 * mm, _titulo.emissao)
            boleto.drawString(160 * mm, 213 * mm, self.agencia_cedente)
            boleto.drawString(41 * mm, 205 * mm, self.banco.carteira)
            boleto.drawString(56 * mm, 205 * mm, self.cedente.especiemon)
            boleto.drawString(160 * mm, 205 * mm, self.nossoNumeroCompletoEditado)
            boleto.drawString(177 * mm, 197 * mm, _titulo.valor)
            _listaPosicao = [199, 194, 189, 184, 179, 174, 169, 164, 159]
            i = 0
            boleto.setFont('Helvetica-Bold', 8)
            for _obs in _titulo.observacoes:
                boleto.drawString(20 * mm, _listaPosicao[i] * mm, _obs)
                i += 1
                if i > 8:
                    break
            boleto.setFont(self.FONTE_DADOS, self.FONTE_DADOS_TAM)
            boleto.drawString(10 * mm, 151 * mm, _titulo.sacadoNome)
            boleto.drawString(135 * mm, 151 * mm, 'CPF/CNPJ: ' + _titulo.sacadoCpfCnpj)
            boleto.drawString(10 * mm, 148 * mm, _titulo.endereco)
            boleto.drawString(10 * mm, 145 * mm, _titulo.endereco1)
            # linha dividindo o canhoto
            boleto.setLineWidth(0.1)
            boleto.setStrokeColor(colors.gray)
            boleto.line(0, 240 * mm, 210 * mm, 240 * mm)
            # linha dividindo o recibo do Beneficiário e ficha de compensação
            boleto.line(0, 122 * mm, 210 * mm, 122 * mm)

            boleto.setStrokeColor(colors.black)
            boleto.setFillColor(colors.black)

            # abaixo da logo do banco
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 228 * mm, 200 * mm, 228 * mm)
            boleto.setLineWidth(0.2)
            # separadores Beneficiário, data do documento e uso do banco
            boleto.line(7 * mm, 220 * mm, 200 * mm, 220 * mm)
            boleto.line(7 * mm, 212 * mm, 200 * mm, 212 * mm)
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 204 * mm, 158 * mm, 204 * mm)
            boleto.setLineWidth(0.2)
            boleto.line(158 * mm, 204 * mm, 200 * mm, 204 * mm)
            # separador do número do banco
            boleto.line(42 * mm, 228 * mm, 42 * mm, 234 * mm)
            boleto.line(56 * mm, 228 * mm, 56 * mm, 234 * mm)

            # separador coluna cedente e vencimento
            boleto.setLineWidth(1)
            boleto.line(158 * mm, 228 * mm, 158 * mm, 156 * mm)

            # separadores do bloco acima
            boleto.setLineWidth(0.2)
            boleto.line(40 * mm, 204 * mm, 40 * mm, 220 * mm)
            boleto.line(55 * mm, 204 * mm, 55 * mm, 212 * mm)
            boleto.line(70 * mm, 204 * mm, 70 * mm, 220 * mm)
            boleto.line(90 * mm, 212 * mm, 90 * mm, 220 * mm)
            boleto.line(113 * mm, 212 * mm, 113 * mm, 220 * mm)
            boleto.line(123 * mm, 204 * mm, 123 * mm, 212 * mm)

            # separador em branco da quantidade e valor
            boleto.setStrokeColor(colors.white)
            boleto.line(123 * mm, 205 * mm, 123 * mm, 208 * mm)
            boleto.setStrokeColor(colors.black)

            boleto.line(158 * mm, 196 * mm, 200 * mm, 196 * mm)
            boleto.line(158 * mm, 188 * mm, 200 * mm, 188 * mm)
            boleto.line(158 * mm, 180 * mm, 200 * mm, 180 * mm)
            boleto.line(158 * mm, 172 * mm, 200 * mm, 172 * mm)
            boleto.line(158 * mm, 164 * mm, 200 * mm, 164 * mm)
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 156 * mm, 200 * mm, 156 * mm)
            boleto.line(7 * mm, 139 * mm, 200 * mm, 139 * mm)
            boleto.setLineWidth(0.2)

            # Divisor Recibo Beneficiário e autenticação mecânica
            boleto.line(124 * mm, 126 * mm, 124 * mm, 136 * mm)
            boleto.line(124 * mm, 136 * mm, 200 * mm, 136 * mm)
            boleto.line(200 * mm, 126 * mm, 200 * mm, 136 * mm)


            # Ficha de compensação
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM)
            boleto.drawString(7 * mm, 108 * mm, 'Local de pagamento')
            boleto.drawString(160 * mm, 108 * mm, 'Vencimento')
            boleto.drawString(7 * mm, 100 * mm, 'Cedente')
            boleto.drawString(7 * mm, 92 * mm, 'Data do documento')
            boleto.drawString(41 * mm, 92 * mm, 'No. do documento')
            boleto.drawString(71 * mm, 92 * mm, 'Espécie doc')
            boleto.drawString(91 * mm, 92 * mm, 'Aceite')
            boleto.drawString(114 * mm, 92 * mm, 'Data do processamento')
            boleto.drawString(160 * mm, 100 * mm, 'Agência/Código do Beneficiário')
            boleto.drawString(7 * mm, 84 * mm, 'Uso do banco')
            boleto.drawString(41 * mm, 84 * mm, 'Carteira')
            boleto.drawString(56 * mm, 84 * mm, 'Espécie')
            boleto.drawString(71 * mm, 84 * mm, 'Quantidade')
            boleto.drawString(123 * mm, 81 * mm, 'x')
            boleto.drawString(124 * mm, 84 * mm, 'Valor')
            boleto.drawString(160 * mm, 92 * mm, 'Nosso número')
            boleto.drawString(160 * mm, 84 * mm, '(=) Valor do documento')
            boleto.drawString(7 * mm, 77 * mm, 'Instruções de responsabilidade do Beneficiário. Qualquer dúvida sobre este boleto, contate o Beneficiário')
            boleto.drawString(160 * mm, 77 * mm, '(-) Desconto/Abatimento')
            boleto.drawString(160 * mm, 70 * mm, '(-) Outras deduções')
            boleto.drawString(160 * mm, 63 * mm, '(+) Mora/Multa')
            boleto.drawString(160 * mm, 56 * mm, '(+) Outros acréscimos')
            boleto.drawString(160 * mm, 49 * mm, '(=) Valor cobrado')
            boleto.drawString(7 * mm, 42 * mm, 'Pagador')
            boleto.drawString(7 * mm, 29 * mm, 'Pagador/avalista')
            boleto.drawString(135 * mm, 28 * mm, 'CPF/CNPJ')
            boleto.drawString(151 * mm, 25 * mm, 'Autenticação mecânica')

            boleto.setFont('Helvetica-Bold', 14)
            boleto.drawString(58 * mm, 112 * mm, _linhaDigitavel)

            boleto.setFont(self.FONTE_DADOS, self.FONTE_DADOS_TAM)
            boleto.drawString(7 * mm, 104 * mm, self.banco.localPagamento)
            boleto.drawString(180 * mm, 104 * mm, _titulo.vencimento)
            boleto.drawString(7 * mm, 96 * mm, self.linhaCedente)
            boleto.drawString(7 * mm, 88 * mm, _titulo.emissao)
            boleto.drawString(41 * mm, 88 * mm, _titulo.documento)
            boleto.drawString(71 * mm, 88 * mm, self.cedente.especiedoc)
            boleto.drawString(91 * mm, 88 * mm, self.cedente.aceite)
            boleto.drawString(114 * mm, 88 * mm, _titulo.emissao)
            boleto.drawString(160 * mm, 96 * mm, self.agencia_cedente)
            boleto.drawString(41 * mm, 80 * mm, self.banco.carteira)
            boleto.drawString(56 * mm, 80 * mm, self.cedente.especiemon)
            boleto.drawString(71 * mm, 80 * mm, '')
            boleto.drawString(124 * mm, 80 * mm, '')
            boleto.drawString(160 * mm, 88 * mm, self.nossoNumeroCompletoEditado)
            boleto.drawString(177 * mm, 80 * mm, _titulo.valor)

            _listaPosicao = [74, 70.5, 67, 63.5, 60, 56.5, 53, 49.5, 46]
            i = 0
            boleto.setFont('Helvetica-Bold', 8)
            for _obs in _titulo.observacoes:
                boleto.drawString(20 * mm, _listaPosicao[i] * mm, _obs)
                i += 1
                if i > 8:
                    break
            boleto.setFont(self.FONTE_DADOS, self.FONTE_DADOS_TAM)
            boleto.drawString(10 * mm, 38 * mm, _titulo.sacadoNome)
            boleto.drawString(135 * mm, 38 * mm, 'CPF/CNPJ: ' + _titulo.sacadoCpfCnpj)
            boleto.drawString(10 * mm, 35 * mm, _titulo.endereco)
            boleto.drawString(10 * mm, 32 * mm, _titulo.endereco1)

            # Identificação das partes

            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM_ID)
            boleto.drawString(165 * mm, 140 * mm, 'Recibo do Pagador')
            boleto.drawString(163 * mm, 28 * mm, 'Ficha de compensação')
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM)

            # abaixo da logo do banco
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 111 * mm, 200 * mm, 111 * mm)

            # separador do número do banco
            boleto.setLineWidth(0.2)
            boleto.line(42 * mm, 111 * mm, 42 * mm, 116 * mm)
            boleto.line(56 * mm, 111 * mm, 56 * mm, 116 * mm)

            # separador coluna local de pagamento e vencimento
            boleto.setLineWidth(1)
            boleto.line(158 * mm, 44 * mm, 158 * mm, 111 * mm)

            # separadores local de pagamento, cedente, data do documento e uso do banco
            boleto.setLineWidth(0.2)
            boleto.line(7 * mm, 103 * mm, 200 * mm, 103 * mm)
            boleto.line(7 * mm, 95 * mm, 200 * mm, 95 * mm)
            boleto.line(7 * mm, 87 * mm, 200 * mm, 87 * mm)
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 79 * mm, 158 * mm, 79 * mm)
            boleto.setLineWidth(0.2)
            boleto.line(158 * mm, 79 * mm, 200 * mm, 79 * mm)

            # separadores do bloco acima
            boleto.line(40 * mm, 79 * mm, 40 * mm, 95 * mm)
            boleto.line(55 * mm, 79 * mm, 55 * mm, 87 * mm)
            boleto.line(70 * mm, 79 * mm, 70 * mm, 95 * mm)
            boleto.line(90 * mm, 87 * mm, 90 * mm, 95 * mm)
            boleto.line(113 * mm, 87 * mm, 113 * mm, 95 * mm)
            boleto.line(123 * mm, 79 * mm, 123 * mm, 87 * mm)

            # separador em branco da quantidade e valor
            boleto.setStrokeColor(colors.white)
            boleto.line(123 * mm, 80 * mm, 123 * mm, 83 * mm)
            boleto.setStrokeColor(colors.black)

            # separadora valor documento, desconto abatimento
            boleto.line(158 * mm, 72 * mm, 200 * mm, 72 * mm)
            boleto.line(158 * mm, 65 * mm, 200 * mm, 65 * mm)
            boleto.line(158 * mm, 58 * mm, 200 * mm, 58 * mm)

            boleto.line(158 * mm, 51 * mm, 200 * mm, 51 * mm)
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 44 * mm, 200 * mm, 44 * mm)

            # Divisor Ficha de compensação e autenticação mecânica
            boleto.setLineWidth(1)
            boleto.line(7 * mm, 27 * mm, 200 * mm, 27 * mm)

            boleto.setLineWidth(0.2)
            boleto.line(124 * mm, 12 * mm, 124 * mm, 24 * mm)
            boleto.line(124 * mm, 24 * mm, 200 * mm, 24 * mm)
            boleto.line(200 * mm, 12 * mm, 200 * mm, 24 * mm)

            f = Frame(mm, 6 * mm, mm, 21 * mm, showBoundary=0)
            f.addFromList(
                [I2of5(_codigoBarra, xdim=0.1 * mm, barWidth=0.90, barHeight=40.9, checksum=0,
                       bearers=0)],
                boleto)
            return True

        def _imprimirCarne():
            self.FONTE_FORM = 'Helvetica'
            self.FONTE_FORM_TAM = 4
            self.FONTE_FORM_TAM_ID = 6
            self.FONTE_DADOS = 'Times-Roman'
            self.FONTE_DADOS_TAM = 8

            boleto.setStrokeColor(colors.black)
            boleto.setLineWidth(0.1)
            boleto.setFont('Helvetica-Bold', 10)
            try:
                _pos = [283, 197, 111]
                boleto.drawImage(image=dirImg + '%s.jpg' % self.banco.numeroBacen, x=07 * mm,
                                 y=_pos[_nrCarne] * mm, width=26 * mm, height=6 * mm)
                boleto.drawImage(image=dirImg + '%s.jpg' % self.banco.numeroBacen, x=39 * mm,
                                 y=_pos[_nrCarne] * mm, width=26 * mm, height=6 * mm)
            except:
                pass


            # telefone da empresa
            boleto.setFont('Helvetica-Bold', 8)
            boleto.setStrokeColor(colors.black)
            boleto.setFillColor(colors.black)

            #Formulario do Recibo do Pagador
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM_ID)
            _pos = [278, 192, 106]
            boleto.drawString(7 * mm, _pos[_nrCarne] * mm, 'RECIBO DO SACADO')
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM)
            _pos = [274, 188, 102]
            _lin = _pos[_nrCarne]
            boleto.drawString(07 * mm, _lin * mm, 'No.Documento')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Vencimento')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Ag./Cód.Cedente')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Nosso Número')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Vl.Documento')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Desconto')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Outras Deduc/Abat.')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Mora/Multa')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Outros Acres.')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Vl.Cobrado')
            _lin -= 6
            boleto.drawString(07 * mm, _lin * mm, 'Pagador')

            #Formulario da Ficha de compensacao
            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM_ID)
            _pos = [217, 131, 45]
            boleto.drawString(151 * mm, _pos[_nrCarne] * mm, 'FICHA DE COMPENSAÇÃO')
            boleto.drawString(151 * mm, (_pos[_nrCarne] - 3.5) * mm, 'Autenticação no verso')

            boleto.setFont(self.FONTE_FORM, self.FONTE_FORM_TAM)
            _pos = [280, 194, 108]
            _lin = _pos[_nrCarne]
            boleto.drawString(40 * mm, _lin * mm, 'Local de Pagamento')
            boleto.drawString(158 * mm, _lin * mm, 'Vencimento')
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, 'Cedente')
            boleto.drawString(158 * mm, _lin * mm, 'Ab.Cod.Cedente')
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, 'Dt.Emissão')
            boleto.drawString(67 * mm, _lin * mm, 'No.Documento')
            boleto.drawString(97 * mm, _lin * mm, 'Esp.Doc.')
            boleto.drawString(117 * mm, _lin * mm, 'Aceite')
            boleto.drawString(137 * mm, _lin * mm, 'Dt.Proc.')
            boleto.drawString(158 * mm, _lin * mm, 'Nosso Número')
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, 'Uso do Banco')
            boleto.drawString(67 * mm, _lin * mm, 'Carteira')
            boleto.drawString(87 * mm, _lin * mm, 'Esp.Moeda')
            boleto.drawString(103 * mm, _lin * mm, 'Qtde.Moeda')
            boleto.drawString(132 * mm, _lin * mm, 'Valor Moeda')
            boleto.drawString(158 * mm, _lin * mm, 'Valor Doc.')
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, 'Texto de responsabilidade do cedente')
            boleto.drawString(158 * mm, _lin * mm, 'Desconto')
            _lin -= 6
            boleto.drawString(158 * mm, _lin * mm, 'Outras Deduc./Abat.')
            _lin -= 6
            boleto.drawString(158 * mm, _lin * mm, 'Mora/Multa')
            _lin -= 6
            boleto.drawString(158 * mm, _lin * mm, 'Outros Acres.')
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, 'Pagador')
            boleto.drawString(158 * mm, _lin * mm, 'Vl.Cobrado')

            # codigo do banco /Linha digitavel
            boleto.setFont('Helvetica-Bold', 10)
            _pos = [283, 197, 111]
            _lin = _pos[_nrCarne]
            boleto.drawString(70 * mm, _lin * mm, self.bancoComDigito)
            boleto.setFont('Helvetica-Bold', 9)
            boleto.drawString(86 * mm, _lin * mm, _linhaDigitavel)

            # Dados do formulario(Recibo do Beneficiário)
            boleto.setFont(self.FONTE_DADOS, self.FONTE_DADOS_TAM)
            _pos = [271, 185, 99]
            _lin = _pos[_nrCarne]
            boleto.drawString(7 * mm, _lin * mm, _titulo.documento)
            _lin -= 6
            boleto.drawString(7 * mm, _lin * mm, _titulo.vencimento)
            _lin -= 6
            boleto.drawString(7 * mm, _lin * mm, self.agencia_cedente)
            _lin -= 6
            boleto.drawString(7 * mm, _lin * mm, self.nossoNumeroCompletoEditado)
            _lin -= 6
            boleto.drawString(15 * mm, _lin * mm, _titulo.valor)
            _lin -= 36
            if len(_titulo.sacadoNome) > 18:
                boleto.drawString(7 * mm, _lin * mm, _titulo.sacadoNome[:22])
            else:
                boleto.drawString(7 * mm, _lin * mm, _titulo.sacadoNome)

            # Dados do formulario(Ficha de compensacao)
            _pos = [277, 191, 105]
            _lin = _pos[_nrCarne]
            boleto.drawString(40 * mm, _lin * mm, self.banco.localPagamento)
            boleto.drawString(174 * mm, _lin * mm, _titulo.vencimento)
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, self.cedente.nome)
            boleto.drawString(100 * mm, _lin * mm, 'CPF/CNPJ:')
            boleto.drawString(115 * mm, _lin * mm, self.cedente.CpfCnpj)
            boleto.drawString(164 * mm, _lin * mm, self.agencia_cedente)
            _lin -= 6
            boleto.drawString(40 * mm, _lin * mm, _titulo.emissao)
            boleto.drawString(67 * mm, _lin * mm, _titulo.documento)
            boleto.drawString(97 * mm, _lin * mm, self.cedente.especiedoc)
            boleto.drawString(117 * mm, _lin * mm, self.cedente.aceite)
            boleto.drawString(137 * mm, _lin * mm, _titulo.emissao)
            boleto.drawString(158 * mm, _lin * mm, self.nossoNumeroCompletoEditado)
            _lin -= 6
            boleto.drawString(67 * mm, _lin * mm, self.banco.carteira)
            boleto.drawString(87 * mm, _lin * mm, self.cedente.especiemon)
            boleto.drawString(170 * mm, _lin * mm, _titulo.valor)
            _lin -= 6
            i = 0
            for _obs in _titulo.observacoes:
                boleto.drawString(40 * mm, _lin * mm, _obs)
                _lin -= 2.5
                i += 1
                if i > 7:
                    break
            _pos = [231, 145, 59]
            _lin = _pos[_nrCarne]
            boleto.drawString(51 * mm, _lin * mm, _titulo.sacadoNome)
            boleto.drawString(100 * mm, _lin * mm, 'CPF/CNPJ:')
            boleto.drawString(115 * mm, _lin * mm, _titulo.sacadoCpfCnpj)
            _lin -= 3
            boleto.drawString(51 * mm, _lin * mm, _titulo.endereco)
            _lin -= 3
            boleto.drawString(51 * mm, _lin * mm, _titulo.endereco1)

            # linhas do Recibo do Pagador
            boleto.setLineWidth(1)
            boleto.setStrokeColor(colors.gray)
            ## Linha vertical
            _pos = [276, 190, 104]
            _lin1 = _pos[_nrCarne]
            _lin2 = _lin1 - 66
            boleto.line(6 * mm, _lin1 * mm, 6 * mm, _lin2 * mm)
            boleto.setLineWidth(0.2)
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(6 * mm, _lin1 * mm, 34 * mm, _lin1 * mm)

            # linhas da Ficha de compensação
            boleto.setLineWidth(1)
            boleto.setStrokeColor(colors.gray)
            ## Linha vertical
            _pos = [282, 196, 110]
            _lin1 = _pos[_nrCarne]
            _lin2 = _lin1 + 6
            boleto.line(39 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            # Linha vertical separando local de pagamento de vencimento
            _pos = [282, 196, 110]
            _col1 = _pos[_nrCarne]
            _col2 = _col1 - 54
            boleto.line(156 * mm, _col1 * mm, 156 * mm, _col2 * mm)
            boleto.setLineWidth(0.2)
            boleto.line(67 * mm, _lin1 * mm, 67 * mm, _lin2 * mm)
            boleto.line(82 * mm, _lin1 * mm, 82 * mm, _lin2 * mm)
            #Linhas horizontais
            _lin1 -= 6
            boleto.line(39 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(39 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            _lin2 = _lin1 + 6
            boleto.line(66 * mm, _lin1 * mm, 66 * mm, _lin2 * mm)
            boleto.line(96 * mm, _lin1 * mm, 96 * mm, _lin2 * mm)
            boleto.line(116 * mm, _lin1 * mm, 116 * mm, _lin2 * mm)
            boleto.line(136 * mm, _lin1 * mm, 136 * mm, _lin2 * mm)
            boleto.line(39 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            boleto.setLineWidth(1)

            _lin1 -= 6
            _lin2 = _lin1 + 6
            boleto.setLineWidth(0.2)
            boleto.line(66 * mm, _lin1 * mm, 66 * mm, _lin2 * mm)
            boleto.line(86 * mm, _lin1 * mm, 86 * mm, _lin2 * mm)
            boleto.line(102 * mm, _lin1 * mm, 102 * mm, _lin2 * mm)
            boleto.line(131 * mm, _lin1 * mm, 131 * mm, _lin2 * mm)
            boleto.line(39 * mm, _lin1 * mm, 156 * mm, _lin1 * mm)
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.setLineWidth(1)
            boleto.line(39 * mm, _lin1 * mm, 156 * mm, _lin1 * mm)
            boleto.setLineWidth(0.2)
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.line(156 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            _lin1 -= 6
            boleto.setLineWidth(1)
            boleto.line(39 * mm, _lin1 * mm, 189 * mm, _lin1 * mm)
            boleto.setLineWidth(0.1)
            _pos = [209, 123, 37]
            _lin1 = _pos[_nrCarne]
            boleto.line(mm, _lin1 * mm, 200 * mm, _lin1 * mm)

            _pos = [104, 61, 18]
            _lin1 = _pos[_nrCarne]
            _lin2 = _lin1 + 15
            f = Frame(40 * mm, _lin1 * mm, 40 * mm, _lin2 * mm, showBoundary=0)
            f.addFromList(
                [I2of5(_codigoBarra, xdim=0.1 * mm, barWidth=0.85, barHeight=30, checksum=0,
                       bearers=0)],
                boleto)
            return True

        arq_pdf = '/tmp/%s.pdf' % time.strftime('%s')
        boleto = Canvas(arq_pdf)
        _nrCarne = 0
        for _titulo in self.__titulos:
            self.banco.numeroBacen = formataString(str(self.banco.numeroBacen), 3, '0', 'E', 'S',
                                                   'S')
            self.banco.moeda = str(self.banco.moeda)[:1]
            _fator = str(datas.calcDiferenca('19971007', _titulo.vencimento))
            _valor = formataString(_titulo.valor.strip().replace(',', '').replace('.', ''), 10, '0', 'E', 'S', 'S')
            self.banco.convenio = str(self.banco.convenio)
            self.titulo.nossoNroSeq = str(_titulo.nossoNroSeq)
            self.banco.agencia = formataString(str(self.banco.agencia), 4, '0', 'E', 'S', 'S')
            _titulo.sacadoCodigo = formataString(_titulo.sacadoCodigo, 6, '0', 'E', 'S', 'S')
            _titulo.endereco = _titulo.enderecoRua
            if _titulo.enderecoNumero:
                _titulo.endereco += ', ' + str(_titulo.enderecoNumero)
            if _titulo.enderecoBairro:
                _titulo.endereco += ' - ' + _titulo.enderecoBairro
            _titulo.endereco1 = _titulo.enderecoCep or ''
            if _titulo.enderecoCidade:
                _titulo.endereco1 += ' - ' + _titulo.enderecoCidade
            if _titulo.enderecoEstado:
                _titulo.endereco1 += ' - ' + _titulo.enderecoEstado
            if self.banco.numeroBacen == '001':  # Banco do Brasil
                self.banco.carteira = formataString(str(self.banco.carteira), 2, '0', 'E', 'S', 'S')
                self.banco.conta = formataString(str(self.banco.conta), 8, '0', 'E', 'S', 'S')
                _contaDV = calcDigito.baseModulo(self.banco.conta, '98765432', 11, subResto='N')
                if _contaDV == '10':
                    _contaDV = 'X'
                _tamConvenio = len(self.banco.convenio)
                if _tamConvenio < 5:
                    _tamConvenio = 4
                    self.banco.convenio = formataString(self.banco.convenio, 4, '0', 'D')
                    self.titulo.nossoNroSeq = formataString(self.titulo.nossoNroSeq, 7, '0', 'D',
                                                             'S', 'S')
                    self.nossoNumeroCompleto = self.banco.convenio + self.titulo.nossoNroSeq
                    self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                    self.__campoLivre = self.nossoNumeroCompleto + self.banco.agencia + self.banco.conta + self.banco.carteira
                if _tamConvenio > 4 and _tamConvenio < 7:
                    _tamConvenio = 6
                    self.banco.convenio = formataString(self.banco.convenio, 6, '0', 'D')
                    self.titulo.nossoNroSeq = formataString(self.titulo.nossoNroSeq, 5, '0', 'D',
                                                             'S', 'S')
                    self.nossoNumeroCompleto = self.banco.convenio + self.titulo.nossoNroSeq
                    self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                    self.__campoLivre = self.nossoNumeroCompleto + self.banco.agencia + self.banco.conta + self.banco.carteira
                if _tamConvenio > 6:
                    self.titulo.nossoNroSeq = formataString(self.titulo.nossoNroSeq, 10, '0',
                                                             'E', 'S', 'S')
                    self.nossoNumeroCompleto = self.banco.convenio + self.titulo.nossoNroSeq
                    self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                    self.__campoLivre = '000000' + self.nossoNumeroCompleto + self.banco.carteira
                if not self.banco.convenio:
                    self.nossoNumeroCompleto = formataString(self.titulo.nossoNroSeq, 17, '0',
                                                             'E', 'S', 'S')
                    self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                    self.__campoLivre = '000000' + self.nossoNumeroCompleto + self.banco.carteira
                _dv = calcDigito.baseModulo(self.nossoNumeroCompleto, '23456789', 11, 'N')
                if _dv == '10':
                    _dv = 'X'
                _agenciaDV = calcDigito.baseModulo(self.banco.agencia, '98765432', 11, subResto='N')
                if _agenciaDV == '10':
                    _agenciaDV = 'X'
                self.banco.agencia = self.banco.agencia + '-' + _agenciaDV
                self.banco.conta = self.banco.conta + '-' + _contaDV
                self.nossoNumeroCompleto = self.nossoNumeroCompleto + _dv
                self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
            elif self.banco.numeroBacen == '104':  # Caixa
                self.banco.carteira = formataString(str(self.banco.carteira), 2, '0', 'E', 'S', 'S')
                self.banco.convenio = formataString(str(self.banco.convenio), 6, '0', 'E', 'S', 'S')
                _dvConvenio = calcDigito.baseModulo(self.banco.convenio, '765432', 11)
                if _dvConvenio > 10:
                    _dvConvenio = 0
                    self.banco.convenio += str(_dvConvenio)
                self.nossoNumeroCompleto = formataString(
                    self.titulo.nossoNroSeq, 15, '0', 'E', 'S', 'S')
                self.nossoNumeroCompleto = '24' + self.nossoNumeroCompleto
                _dv = calcDigito.baseModulo(self.nossoNumeroCompleto, '98765432', 11)
                if _dv in ('10', '11'):
                    _dv = '0'
                self.nossoNumeroCompleto = self.nossoNumeroCompleto + _dv
                self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto[:2] +'/' + \
                                                    self.nossoNumeroCompleto[2:-1]+'-' + \
                                                    self.nossoNumeroCompleto[-1:]
                self.__campoLivre = self.banco.convenio + self.nossoNumeroCompleto[2:5] + \
                                    self.nossoNumeroCompleto[:1] + \
                                    self.nossoNumeroCompleto[5:8] + self.nossoNumeroCompleto[1:2] + \
                                    self.nossoNumeroCompleto[8:17]
                _dv = calcDigito.baseModulo(self.__campoLivre, '98765432', 11)
                if _dv in ('10', '11'):
                    _dv = '0'
                self.__campoLivre = self.__campoLivre + _dv
            elif self.banco.numeroBacen == '237':  # Bradesco
                self.banco.carteira = formataString(str(self.banco.carteira), 2, '0', 'E', 'S', 'S')
                self.banco.conta = formataString(str(self.banco.conta), 7, '0', 'E', 'S', 'S')
                self.nossoNumeroCompleto = formataString(self.titulo.nossoNroSeq, 11, '0', 'D',
                                                         'S',
                                                         'S')
                self.__campoLivre = self.banco.agencia + self.banco.carteira + self.nossoNumeroCompleto + self.banco.conta + '0'
                _dv = calcDigito.baseModulo(self.banco.carteira + self.nossoNumeroCompleto,
                                            '765432', 11)
                if _dv == '10':
                    _dv = 'P'
                if _dv == '11':
                    _dv = '0'
                self.nossoNumeroCompleto = self.nossoNumeroCompleto + _dv
                self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
            elif self.banco.numeroBacen == '341':  # Itau
                self.banco.carteira = formataString(str(self.banco.carteira), 3, '0', 'E', 'S', 'S')
                self.banco.conta = formataString(str(self.banco.conta), 5, '0', 'E', 'S', 'S')
                self.titulo.nossoNroSeq = formataString(self.titulo.nossoNroSeq, 8, '0', 'E', 'S',
                                                         'S')
                self.nossoNumeroCompleto = self.banco.carteira + self.titulo.nossoNroSeq
                _dv = calcDigito.baseModulo(self.nossoNumeroCompleto, '12', 10, somaDigitos='S')
                if _dv == '10':
                    _dv = '0'
                self.nossoNumeroCompleto = self.nossoNumeroCompleto + _dv
                self.nossoNumeroCompletoEditado = (self.nossoNumeroCompleto[:3] + '/'
                                                + self.nossoNumeroCompleto[3:-1] + '-'
                                                + self.nossoNumeroCompleto[-1:]
                                                   )
                _ac_dv = calcDigito.baseModulo(self.banco.agencia + self.banco.conta, '12', 10,
                                               somaDigitos='S')
                if _ac_dv == '10':
                    _ac_dv = '0'
                self.__campoLivre = self.banco.carteira + self.titulo.nossoNroSeq + _dv + self.banco.agencia + self.banco.conta + _ac_dv + '000'
            elif self.banco.numeroBacen == '756': #Sicoob
                self.banco.carteira = formataString(str(self.banco.carteira), 1, '0', 'E', 'S', 'S')
                self.banco.conta = formataString(str(self.banco.conta), 7, '0', 'E', 'S', 'S')
                _convenio = self.banco.convenio
                if len(_convenio) > 7:
                    _convenio = _convenio[-7:]
                else:
                    _convenio = str(_convenio).zfill(7)
                if len(str(_titulo.parcela)) > 3:
                    _parcela = _titulo.parcela[-3:]
                else:
                    _parcela = str(_titulo.parcela).zfill(3)
                # O numero do cliente eh o dado informado no campo convenio do cadastro de local e
                # natureza
                _clienteNossoNumero = _convenio.zfill(10)
                _agenciaNossoNumero = str(self.banco.agencia).zfill(4)
                _nossoNumeroSeq = str(self.titulo.nossoNroSeq).zfill(7)
                self.nossoNumeroCompleto = _agenciaNossoNumero + _clienteNossoNumero + _nossoNumeroSeq
                self.nossoNumeroCompleto = formataString(self.nossoNumeroCompleto, 21, '0', 'D',
                                                         'S', 'S')
                _dv = calcDigito.baseModulo(self.nossoNumeroCompleto, '1973',
                                            11, 'S', 'N')
                if _dv == '10':
                    _dv = '0'
                if _dv == '11':
                    _dv = '0'
                self.nossoNumeroCompleto = _nossoNumeroSeq + _dv
                self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                self.__campoLivre = self.banco.carteira + self.banco.agencia + \
                    self.banco.modalidade + _convenio + self.nossoNumeroCompleto + _parcela
            else:
                self.banco.carteira = formataString(str(self.banco.carteira), 2, '0', 'E', 'S', 'S')
                self.titulo.nossoNroSeq = formataString(self.titulo.nossoNroSeq, 11, '0', 'E',
                                                         'S', 'S')
                self.nossoNumeroCompleto = self.titulo.nossoNroSeq
                self.nossoNumeroCompletoEditado = self.nossoNumeroCompleto
                self.__campoLivre = _titulo.sacadoCodigo + _titulo.documento
                self.__campoLivre = formataString(self.__campoLivre, 25, '0', 'D', 'S', 'S')
            self.linhaCedente = self.cedente.nome + '        ' + \
                                self.cedente.CpfCnpj

            _codigoBarra = self.banco.numeroBacen + self.banco.moeda + 'X' + _fator + _valor + self.__campoLivre
            _dv = calcDigito.baseModulo(_codigoBarra.replace('X', ''), '98765432', 11)
            if _dv in ('0', '10', '11'):
                _dv = '1'
            _codigoBarraDV = _dv
            _codigoBarra = _codigoBarra.replace('X', _codigoBarraDV)
            _campoDig1 = _codigoBarra[:4] + _codigoBarra[19:24]
            _campoDig2 = _codigoBarra[24:34]
            _campoDig3 = _codigoBarra[34:]
            _campoDig5 = _codigoBarra[5:19]
            _dv = calcDigito.baseModulo(_campoDig1, '12', 10, somaDigitos='S')
            if _dv == '10':
                _dv = '0'
            _campoDig1 = _campoDig1 + _dv
            _dv = calcDigito.baseModulo(_campoDig2, '12', 10, somaDigitos='S')
            if _dv == '10':
                _dv = '0'
            _campoDig2 = _campoDig2 + _dv
            _dv = calcDigito.baseModulo(_campoDig3, '12', 10, somaDigitos='S')
            if _dv == '10':
                _dv = '0'
            _campoDig3 = _campoDig3 + _dv
            _linhaDigitavel = _campoDig1[:5] + '.' + _campoDig1[5:] + ' ' \
                              + _campoDig2[:5] + '.' + _campoDig2[5:] + ' ' \
                              + _campoDig3[:5] + '.' + _campoDig3[5:] + ' ' \
                              + _codigoBarraDV + ' ' \
                              + _campoDig5
            self.titulo.codigoBarras = _linhaDigitavel
            _titulo.codigoBarras = _linhaDigitavel

            _dv = calcDigito.baseModulo(self.banco.numeroBacen, '98765432', 11)
            if _dv in ('11', '10'):
                _dv = '0'
            self.bancoComDigito = str(self.banco.numeroBacen) + '-' + _dv
            if self.banco.convenio:
                if self.banco.numeroBacen == '104':
                    self.agencia_cedente = self.banco.agencia + '/' \
                                    + self.banco.convenio[:6] + '-' + self.banco.convenio[-1:]
                else:
                    self.agencia_cedente = self.banco.agencia + '/' + self.banco.convenio
            else:
                if self.banco.numeroBacen == '341':
                    self.agencia_cedente = self.banco.agencia + '/' + self.banco.conta + '-' + self.banco.conta_dv
                else:
                    self.agencia_cedente = self.banco.agencia + '/' + self.banco.conta

            if self.banco.formato == 'B':
                _imprimirBoleto()
                boleto.save()
            else:
                _imprimirCarne()
                _nrCarne += 1
                if _nrCarne == 3:
                    _nrCarne = 0
                    boleto.save()
        if self.banco.formato == 'C':
            if _nrCarne != 0:
                boleto.save()
        if os.name == 'posix':
            # imprimir o arquivo
            if self.cedente.impressora[:7] == 'arquivo':
                a = 'mv ' + arq_pdf + ' ' + self.cedente.impressora[7:].strip()
            else:
                a = 'lpr ' + arq_pdf + ' -P ' + self.cedente.impressora + ' -oPageSize=A4'
            os.system(a)


